# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from ...ocsf.v_1_3_0.accountchange.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_accountchange_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.actor import (
    Actor as ocsf_v_1_3_0_accountchange_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.api import (
    Api as ocsf_v_1_3_0_accountchange_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.accountchange.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_accountchange_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.accountchange.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_accountchange_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_accountchange_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.object import (
    Object as ocsf_v_1_3_0_accountchange_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.device import (
    Device as ocsf_v_1_3_0_accountchange_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.accountchange.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_accountchange_base_types_timestamp_Timestamp,
)
import datetime as dt
from ...ocsf.v_1_3_0.accountchange.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_accountchange_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_accountchange_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_accountchange_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.observable import (
    Observable as ocsf_v_1_3_0_accountchange_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.osint import (
    Osint as ocsf_v_1_3_0_accountchange_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.policy import (
    Policy as ocsf_v_1_3_0_accountchange_objects_types_policy_Policy,
)
from ...ocsf.v_1_3_0.accountchange.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_accountchange_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_accountchange_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.accountchange.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_accountchange_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.accountchange.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_accountchange_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.accountchange.objects.types.user import (
    User as ocsf_v_1_3_0_accountchange_objects_types_user_User,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...ocsf.v_1_3_0.apiactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_apiactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_apiactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_apiactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.apiactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_apiactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.apiactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_apiactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_apiactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_apiactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_apiactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.apiactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_apiactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_apiactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_apiactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_apiactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_apiactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_apiactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.apiactivity.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_apiactivity_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.apiactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_apiactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.apiactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_apiactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.apiactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_apiactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.action_id import (
    ActionId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.activity_id import (
    ActivityId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.actor import (
    Actor as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_actor_Actor,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.api import (
    Api as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_api_Api,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.application import (
    Application,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.attack import (
    Attack as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_attack_Attack,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.authorization import (
    Authorization as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.class_uid import (
    ClassUid as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.cloud import (
    Cloud as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.compliance import (
    Compliance as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_compliance_Compliance,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.object import (
    Object as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_object_Object,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.device import (
    Device as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_device_Device,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.base.types.timestamp import (
    Timestamp as ocsf_v_1_5_0_applicationsecurityposturefinding_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.enrichment import (
    Enrichment as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.finding_info import (
    FindingInfo as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_finding_info_FindingInfo,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.malware import (
    Malware as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_malware_Malware,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.malware_scan_info import (
    MalwareScanInfo as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_malware_scan_info_MalwareScanInfo,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.metadata import (
    Metadata as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.observable import (
    Observable as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_observable_Observable,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.osint import (
    Osint as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_osint_Osint,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.policy import (
    Policy as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_policy_Policy,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.remediation import (
    Remediation as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_remediation_Remediation,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.severity_id import (
    SeverityId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.status_id import (
    StatusId as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.classes.types.type_uid import (
    TypeUid as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.vendor_attributes import (
    VendorAttributes,
)
from ...ocsf.v_1_5_0.applicationsecurityposturefinding.objects.types.vulnerability import (
    Vulnerability as ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_vulnerability_Vulnerability,
)
from ...ocsf.v_1_3_0.entitymanagement.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_entitymanagement_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.actor import (
    Actor as ocsf_v_1_3_0_entitymanagement_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.api import (
    Api as ocsf_v_1_3_0_entitymanagement_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.entitymanagement.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_entitymanagement_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.entitymanagement.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_entitymanagement_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_entitymanagement_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.object import (
    Object as ocsf_v_1_3_0_entitymanagement_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.device import (
    Device as ocsf_v_1_3_0_entitymanagement_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.entitymanagement.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_entitymanagement_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_entitymanagement_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.managed_entity import ManagedEntity
from ...ocsf.v_1_3_0.entitymanagement.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_entitymanagement_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_entitymanagement_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.observable import (
    Observable as ocsf_v_1_3_0_entitymanagement_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.osint import (
    Osint as ocsf_v_1_3_0_entitymanagement_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.entitymanagement.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_entitymanagement_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.entitymanagement.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_entitymanagement_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.entitymanagement.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_entitymanagement_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.entitymanagement.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_entitymanagement_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.authentication.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_authentication_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.authentication.objects.types.actor import (
    Actor as ocsf_v_1_3_0_authentication_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.authentication.objects.types.api import (
    Api as ocsf_v_1_3_0_authentication_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.authentication.objects.types.auth_factor import AuthFactor
from ...ocsf.v_1_3_0.authentication.classes.types.auth_protocol_id import AuthProtocolId
from ...ocsf.v_1_3_0.authentication.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_authentication_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.authentication.objects.types.certificate import Certificate
from ...ocsf.v_1_3_0.authentication.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_authentication_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.authentication.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_authentication_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.authentication.objects.types.object import (
    Object as ocsf_v_1_3_0_authentication_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.authentication.objects.types.device import (
    Device as ocsf_v_1_3_0_authentication_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.authentication.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_authentication_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.authentication.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_authentication_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.authentication.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_authentication_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.authentication.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_authentication_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.authentication.objects.types.process import (
    Process as ocsf_v_1_3_0_authentication_objects_types_process_Process,
)
from ...ocsf.v_1_3_0.authentication.classes.types.logon_type_id import LogonTypeId
from ...ocsf.v_1_3_0.authentication.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_authentication_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.authentication.objects.types.observable import (
    Observable as ocsf_v_1_3_0_authentication_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.authentication.objects.types.osint import (
    Osint as ocsf_v_1_3_0_authentication_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.authentication.objects.types.service import Service
from ...ocsf.v_1_3_0.authentication.objects.types.session import (
    Session as ocsf_v_1_3_0_authentication_objects_types_session_Session,
)
from ...ocsf.v_1_3_0.authentication.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_authentication_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.authentication.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_authentication_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.authentication.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_authentication_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.authentication.objects.types.user import (
    User as ocsf_v_1_3_0_authentication_objects_types_user_User,
)
from ...ocsf.v_1_3_0.authorizesession.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_authorizesession_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.actor import (
    Actor as ocsf_v_1_3_0_authorizesession_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.api import (
    Api as ocsf_v_1_3_0_authorizesession_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.authorizesession.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_authorizesession_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.authorizesession.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_authorizesession_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_authorizesession_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.object import (
    Object as ocsf_v_1_3_0_authorizesession_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.device import (
    Device as ocsf_v_1_3_0_authorizesession_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_authorizesession_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.authorizesession.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_authorizesession_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_authorizesession_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.group import (
    Group as ocsf_v_1_3_0_authorizesession_objects_types_group_Group,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_authorizesession_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_authorizesession_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.observable import (
    Observable as ocsf_v_1_3_0_authorizesession_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.osint import (
    Osint as ocsf_v_1_3_0_authorizesession_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.session import (
    Session as ocsf_v_1_3_0_authorizesession_objects_types_session_Session,
)
from ...ocsf.v_1_3_0.authorizesession.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_authorizesession_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.authorizesession.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_authorizesession_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.authorizesession.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_authorizesession_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.authorizesession.objects.types.user import (
    User as ocsf_v_1_3_0_authorizesession_objects_types_user_User,
)
from ...ocsf.v_1_3_0.baseevent.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_baseevent_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.api import (
    Api as ocsf_v_1_3_0_baseevent_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.baseevent.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_baseevent_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.baseevent.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_baseevent_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_baseevent_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.object import (
    Object as ocsf_v_1_3_0_baseevent_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.baseevent.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_baseevent_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_baseevent_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_baseevent_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.observable import (
    Observable as ocsf_v_1_3_0_baseevent_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.baseevent.objects.types.osint import (
    Osint as ocsf_v_1_3_0_baseevent_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.baseevent.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_baseevent_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.baseevent.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_baseevent_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_compliancefinding_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.actor import (
    Actor as ocsf_v_1_3_0_compliancefinding_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.api import (
    Api as ocsf_v_1_3_0_compliancefinding_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_compliancefinding_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_compliancefinding_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_compliancefinding_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.compliance import (
    Compliance as ocsf_v_1_3_0_compliancefinding_objects_types_compliance_Compliance,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_3_0_compliancefinding_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.object import (
    Object as ocsf_v_1_3_0_compliancefinding_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.device import (
    Device as ocsf_v_1_3_0_compliancefinding_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.compliancefinding.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_compliancefinding_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_compliancefinding_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.finding_info import (
    FindingInfo as ocsf_v_1_3_0_compliancefinding_objects_types_finding_info_FindingInfo,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_compliancefinding_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.observable import (
    Observable as ocsf_v_1_3_0_compliancefinding_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.osint import (
    Osint as ocsf_v_1_3_0_compliancefinding_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.remediation import (
    Remediation as ocsf_v_1_3_0_compliancefinding_objects_types_remediation_Remediation,
)
from ...ocsf.v_1_3_0.compliancefinding.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_compliancefinding_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_compliancefinding_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_compliancefinding_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.compliancefinding.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_compliancefinding_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.configstate.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_configstate_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.configstate.objects.types.actor import (
    Actor as ocsf_v_1_3_0_configstate_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.configstate.objects.types.api import (
    Api as ocsf_v_1_3_0_configstate_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.configstate.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_configstate_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.configstate.objects.types.cis_benchmark_result import (
    CisBenchmarkResult,
)
from ...ocsf.v_1_3_0.configstate.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_configstate_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.configstate.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_configstate_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.configstate.objects.types.object import (
    Object as ocsf_v_1_3_0_configstate_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.configstate.objects.types.device import (
    Device as ocsf_v_1_3_0_configstate_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.configstate.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_configstate_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.configstate.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_configstate_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.configstate.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_configstate_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.configstate.objects.types.observable import (
    Observable as ocsf_v_1_3_0_configstate_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.configstate.objects.types.osint import (
    Osint as ocsf_v_1_3_0_configstate_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.configstate.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_configstate_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.configstate.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_configstate_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.configstate.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_configstate_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_detectionfinding_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_detectionfinding_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.actor import (
    Actor as ocsf_v_1_3_0_detectionfinding_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.api import (
    Api as ocsf_v_1_3_0_detectionfinding_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.attack import (
    Attack as ocsf_v_1_3_0_detectionfinding_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_detectionfinding_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_detectionfinding_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_detectionfinding_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_detectionfinding_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_3_0_detectionfinding_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.object import (
    Object as ocsf_v_1_3_0_detectionfinding_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.device import (
    Device as ocsf_v_1_3_0_detectionfinding_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_detectionfinding_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.detectionfinding.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_detectionfinding_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_detectionfinding_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.evidences import Evidences
from ...ocsf.v_1_3_0.detectionfinding.objects.types.finding_info import (
    FindingInfo as ocsf_v_1_3_0_detectionfinding_objects_types_finding_info_FindingInfo,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_detectionfinding_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.impact_id import (
    ImpactId as ocsf_v_1_3_0_detectionfinding_classes_types_impact_id_ImpactId,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.malware import (
    Malware as ocsf_v_1_3_0_detectionfinding_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_detectionfinding_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.observable import (
    Observable as ocsf_v_1_3_0_detectionfinding_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.osint import (
    Osint as ocsf_v_1_3_0_detectionfinding_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.remediation import (
    Remediation as ocsf_v_1_3_0_detectionfinding_objects_types_remediation_Remediation,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_detectionfinding_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_3_0_detectionfinding_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_detectionfinding_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_detectionfinding_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.detectionfinding.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_detectionfinding_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.detectionfinding.objects.types.vulnerability import (
    Vulnerability as ocsf_v_1_3_0_detectionfinding_objects_types_vulnerability_Vulnerability,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_dnsactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_dnsactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_dnsactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.dns_answer import DnsAnswer
from ...ocsf.v_1_3_0.dnsactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_dnsactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.attack import (
    Attack as ocsf_v_1_3_0_dnsactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_dnsactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_dnsactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_dnsactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_dnsactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.network_connection_info import (
    NetworkConnectionInfo as ocsf_v_1_3_0_dnsactivity_objects_types_network_connection_info_NetworkConnectionInfo,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_dnsactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_dnsactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_dnsactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_dnsactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.dnsactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_dnsactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_dnsactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_dnsactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.ja_4_fingerprint import (
    Ja4Fingerprint as ocsf_v_1_3_0_dnsactivity_objects_types_ja_4_fingerprint_Ja4Fingerprint,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.load_balancer import (
    LoadBalancer as ocsf_v_1_3_0_dnsactivity_objects_types_load_balancer_LoadBalancer,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.malware import (
    Malware as ocsf_v_1_3_0_dnsactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_dnsactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_dnsactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_dnsactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.network_proxy import (
    NetworkProxy as ocsf_v_1_3_0_dnsactivity_objects_types_network_proxy_NetworkProxy,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_dnsactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.http_response import (
    HttpResponse as ocsf_v_1_3_0_dnsactivity_objects_types_http_response_HttpResponse,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.tls import (
    Tls as ocsf_v_1_3_0_dnsactivity_objects_types_tls_Tls,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.network_traffic import (
    NetworkTraffic as ocsf_v_1_3_0_dnsactivity_objects_types_network_traffic_NetworkTraffic,
)
from ...ocsf.v_1_3_0.dnsactivity.objects.types.dns_query import DnsQuery
from ...ocsf.v_1_3_0.dnsactivity.classes.types.rcode_id import RcodeId
from ...ocsf.v_1_3_0.dnsactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_dnsactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_dnsactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.dnsactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_dnsactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_6_0_httpactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_6_0_httpactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.actor import (
    Actor as ocsf_v_1_6_0_httpactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.api import (
    Api as ocsf_v_1_6_0_httpactivity_objects_types_api_Api,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.attack import (
    Attack as ocsf_v_1_6_0_httpactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_6_0_httpactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_6_0_httpactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_6_0_httpactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_6_0_httpactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_6_0_httpactivity_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.network_connection_info import (
    NetworkConnectionInfo as ocsf_v_1_6_0_httpactivity_objects_types_network_connection_info_NetworkConnectionInfo,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.object import (
    Object as ocsf_v_1_6_0_httpactivity_objects_types_object_Object,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.device import (
    Device as ocsf_v_1_6_0_httpactivity_objects_types_device_Device,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_6_0_httpactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_6_0_httpactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_6_0.httpactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_6_0_httpactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_6_0_httpactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.file import (
    File as ocsf_v_1_6_0_httpactivity_objects_types_file_File,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_6_0_httpactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.http_cookie import HttpCookie
from ...ocsf.v_1_6_0.httpactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_6_0_httpactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.http_response import (
    HttpResponse as ocsf_v_1_6_0_httpactivity_objects_types_http_response_HttpResponse,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.ja_4_fingerprint import (
    Ja4Fingerprint as ocsf_v_1_6_0_httpactivity_objects_types_ja_4_fingerprint_Ja4Fingerprint,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.load_balancer import (
    LoadBalancer as ocsf_v_1_6_0_httpactivity_objects_types_load_balancer_LoadBalancer,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.malware import (
    Malware as ocsf_v_1_6_0_httpactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.malware_scan_info import (
    MalwareScanInfo as ocsf_v_1_6_0_httpactivity_objects_types_malware_scan_info_MalwareScanInfo,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_6_0_httpactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.observable import (
    Observable as ocsf_v_1_6_0_httpactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.osint import (
    Osint as ocsf_v_1_6_0_httpactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.policy import (
    Policy as ocsf_v_1_6_0_httpactivity_objects_types_policy_Policy,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.network_proxy import (
    NetworkProxy as ocsf_v_1_6_0_httpactivity_objects_types_network_proxy_NetworkProxy,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.tls import (
    Tls as ocsf_v_1_6_0_httpactivity_objects_types_tls_Tls,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.network_traffic import (
    NetworkTraffic as ocsf_v_1_6_0_httpactivity_objects_types_network_traffic_NetworkTraffic,
)
from ...ocsf.v_1_6_0.httpactivity.objects.types.fingerprint import (
    Fingerprint as ocsf_v_1_6_0_httpactivity_objects_types_fingerprint_Fingerprint,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_6_0_httpactivity_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_6_0_httpactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_6_0_httpactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_6_0.httpactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_6_0_httpactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_fileactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_fileactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_fileactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_fileactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.attack import (
    Attack as ocsf_v_1_3_0_fileactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_fileactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_fileactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_fileactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_fileactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_fileactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_fileactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_fileactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.fileactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_fileactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_fileactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.file import (
    File as ocsf_v_1_3_0_fileactivity_objects_types_file_File,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_fileactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.malware import (
    Malware as ocsf_v_1_3_0_fileactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_fileactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_fileactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.fileactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_fileactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_fileactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_fileactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.fileactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_fileactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.groupmanagement.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_groupmanagement_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.actor import (
    Actor as ocsf_v_1_3_0_groupmanagement_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.api import (
    Api as ocsf_v_1_3_0_groupmanagement_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.groupmanagement.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_groupmanagement_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.groupmanagement.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_groupmanagement_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_groupmanagement_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.object import (
    Object as ocsf_v_1_3_0_groupmanagement_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.device import (
    Device as ocsf_v_1_3_0_groupmanagement_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.groupmanagement.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_groupmanagement_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_groupmanagement_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.group import (
    Group as ocsf_v_1_3_0_groupmanagement_objects_types_group_Group,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_groupmanagement_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_groupmanagement_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.observable import (
    Observable as ocsf_v_1_3_0_groupmanagement_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.osint import (
    Osint as ocsf_v_1_3_0_groupmanagement_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_groupmanagement_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.groupmanagement.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_groupmanagement_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_groupmanagement_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.groupmanagement.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_groupmanagement_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.groupmanagement.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_groupmanagement_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.groupmanagement.objects.types.user import (
    User as ocsf_v_1_3_0_groupmanagement_objects_types_user_User,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_incidentfinding_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.api import (
    Api as ocsf_v_1_3_0_incidentfinding_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.user import (
    User as ocsf_v_1_3_0_incidentfinding_objects_types_user_User,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.group import (
    Group as ocsf_v_1_3_0_incidentfinding_objects_types_group_Group,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.attack import (
    Attack as ocsf_v_1_3_0_incidentfinding_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_incidentfinding_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_incidentfinding_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_incidentfinding_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_3_0_incidentfinding_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.object import (
    Object as ocsf_v_1_3_0_incidentfinding_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.incidentfinding.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_incidentfinding_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_incidentfinding_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.finding_info import (
    FindingInfo as ocsf_v_1_3_0_incidentfinding_objects_types_finding_info_FindingInfo,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.impact_id import (
    ImpactId as ocsf_v_1_3_0_incidentfinding_classes_types_impact_id_ImpactId,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_incidentfinding_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.observable import (
    Observable as ocsf_v_1_3_0_incidentfinding_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.osint import (
    Osint as ocsf_v_1_3_0_incidentfinding_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.priority_id import PriorityId
from ...ocsf.v_1_3_0.incidentfinding.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_incidentfinding_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.incidentfinding.base.types.url_string import UrlString
from ...ocsf.v_1_3_0.incidentfinding.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_incidentfinding_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.incidentfinding.objects.types.ticket import Ticket
from ...ocsf.v_1_3_0.incidentfinding.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_incidentfinding_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.incidentfinding.classes.types.verdict_id import VerdictId
from ...ocsf.v_1_3_0.inventoryinfo.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_inventoryinfo_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.actor import (
    Actor as ocsf_v_1_3_0_inventoryinfo_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.api import (
    Api as ocsf_v_1_3_0_inventoryinfo_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.inventoryinfo.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_inventoryinfo_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.inventoryinfo.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_inventoryinfo_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_inventoryinfo_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.object import (
    Object as ocsf_v_1_3_0_inventoryinfo_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.device import (
    Device as ocsf_v_1_3_0_inventoryinfo_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.inventoryinfo.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_inventoryinfo_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_inventoryinfo_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_inventoryinfo_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.observable import (
    Observable as ocsf_v_1_3_0_inventoryinfo_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.inventoryinfo.objects.types.osint import (
    Osint as ocsf_v_1_3_0_inventoryinfo_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.inventoryinfo.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_inventoryinfo_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.inventoryinfo.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_inventoryinfo_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.inventoryinfo.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_inventoryinfo_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_moduleactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_moduleactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_moduleactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_moduleactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.attack import (
    Attack as ocsf_v_1_3_0_moduleactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_moduleactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_moduleactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_moduleactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_moduleactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_moduleactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_moduleactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_moduleactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.moduleactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_moduleactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_moduleactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_moduleactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.malware import (
    Malware as ocsf_v_1_3_0_moduleactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_moduleactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.module import (
    Module as ocsf_v_1_3_0_moduleactivity_objects_types_module_Module,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_moduleactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.moduleactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_moduleactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_moduleactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_moduleactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.moduleactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_moduleactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_networkactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_networkactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_networkactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_networkactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.attack import (
    Attack as ocsf_v_1_3_0_networkactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_networkactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_networkactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_networkactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_networkactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.network_connection_info import (
    NetworkConnectionInfo as ocsf_v_1_3_0_networkactivity_objects_types_network_connection_info_NetworkConnectionInfo,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_networkactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_networkactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_networkactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_networkactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.networkactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_networkactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_networkactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_networkactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.ja_4_fingerprint import (
    Ja4Fingerprint as ocsf_v_1_3_0_networkactivity_objects_types_ja_4_fingerprint_Ja4Fingerprint,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.load_balancer import (
    LoadBalancer as ocsf_v_1_3_0_networkactivity_objects_types_load_balancer_LoadBalancer,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.malware import (
    Malware as ocsf_v_1_3_0_networkactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_networkactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_networkactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_networkactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.network_proxy import (
    NetworkProxy as ocsf_v_1_3_0_networkactivity_objects_types_network_proxy_NetworkProxy,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_networkactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.http_response import (
    HttpResponse as ocsf_v_1_3_0_networkactivity_objects_types_http_response_HttpResponse,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.tls import (
    Tls as ocsf_v_1_3_0_networkactivity_objects_types_tls_Tls,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.network_traffic import (
    NetworkTraffic as ocsf_v_1_3_0_networkactivity_objects_types_network_traffic_NetworkTraffic,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_networkactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_networkactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.networkactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_networkactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.networkactivity.objects.types.url import Url
from ...ocsf.v_1_3_0.processactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_processactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_processactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_processactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_processactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.attack import (
    Attack as ocsf_v_1_3_0_processactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_processactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_processactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_processactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_processactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_processactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_processactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_processactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.processactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_processactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_processactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_processactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.injection_type_id import (
    InjectionTypeId,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.malware import (
    Malware as ocsf_v_1_3_0_processactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_processactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.module import (
    Module as ocsf_v_1_3_0_processactivity_objects_types_module_Module,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_processactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_processactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.processactivity.objects.types.process import (
    Process as ocsf_v_1_3_0_processactivity_objects_types_process_Process,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_processactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_processactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.processactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_processactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.scanactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_scanactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_scanactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.agent import Agent
from ...ocsf.v_1_3_0.scanactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_scanactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.scanactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_scanactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.scanactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_scanactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_scanactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_scanactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_scanactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.scanactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_scanactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_scanactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_scanactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_scanactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_scanactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.policy import (
    Policy as ocsf_v_1_3_0_scanactivity_objects_types_policy_Policy,
)
from ...ocsf.v_1_3_0.scanactivity.objects.types.scan import Scan
from ...ocsf.v_1_3_0.scanactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_scanactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.scanactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_scanactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.scanactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_scanactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_3_0_scheduledjobactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_scheduledjobactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_scheduledjobactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_scheduledjobactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.attack import (
    Attack as ocsf_v_1_3_0_scheduledjobactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_3_0_scheduledjobactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_scheduledjobactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_scheduledjobactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_scheduledjobactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_scheduledjobactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_scheduledjobactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_3_0_scheduledjobactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_scheduledjobactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_scheduledjobactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_3_0_scheduledjobactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.job import Job
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.malware import (
    Malware as ocsf_v_1_3_0_scheduledjobactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_scheduledjobactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_scheduledjobactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_scheduledjobactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_scheduledjobactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_scheduledjobactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.scheduledjobactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_scheduledjobactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_securityfinding_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.analytic import Analytic
from ...ocsf.v_1_3_0.securityfinding.objects.types.api import (
    Api as ocsf_v_1_3_0_securityfinding_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.attack import (
    Attack as ocsf_v_1_3_0_securityfinding_objects_types_attack_Attack,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_securityfinding_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.cis_csc import CisCsc
from ...ocsf.v_1_3_0.securityfinding.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_securityfinding_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_securityfinding_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.compliance import (
    Compliance as ocsf_v_1_3_0_securityfinding_objects_types_compliance_Compliance,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_3_0_securityfinding_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.object import (
    Object as ocsf_v_1_3_0_securityfinding_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.securityfinding.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_securityfinding_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_securityfinding_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.finding import Finding
from ...ocsf.v_1_3_0.securityfinding.classes.types.impact_id import (
    ImpactId as ocsf_v_1_3_0_securityfinding_classes_types_impact_id_ImpactId,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.kill_chain_phase import (
    KillChainPhase,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.malware import (
    Malware as ocsf_v_1_3_0_securityfinding_objects_types_malware_Malware,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_securityfinding_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.observable import (
    Observable as ocsf_v_1_3_0_securityfinding_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.osint import (
    Osint as ocsf_v_1_3_0_securityfinding_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.process import (
    Process as ocsf_v_1_3_0_securityfinding_objects_types_process_Process,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_securityfinding_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_3_0_securityfinding_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_securityfinding_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.state_id import StateId
from ...ocsf.v_1_3_0.securityfinding.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_securityfinding_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.securityfinding.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_securityfinding_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.securityfinding.objects.types.vulnerability import (
    Vulnerability as ocsf_v_1_3_0_securityfinding_objects_types_vulnerability_Vulnerability,
)
from ...ocsf.v_1_3_0.softwareinfo.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_softwareinfo_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.api import (
    Api as ocsf_v_1_3_0_softwareinfo_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.softwareinfo.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_softwareinfo_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.softwareinfo.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_softwareinfo_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_softwareinfo_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.object import (
    Object as ocsf_v_1_3_0_softwareinfo_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.device import (
    Device as ocsf_v_1_3_0_softwareinfo_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.softwareinfo.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_softwareinfo_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_softwareinfo_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_softwareinfo_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.observable import (
    Observable as ocsf_v_1_3_0_softwareinfo_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.osint import (
    Osint as ocsf_v_1_3_0_softwareinfo_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.softwareinfo.objects.types.product import (
    Product as ocsf_v_1_3_0_softwareinfo_objects_types_product_Product,
)
from ...ocsf.v_1_3_0.softwareinfo.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_softwareinfo_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.softwareinfo.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_softwareinfo_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.softwareinfo.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_softwareinfo_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.useraccessmanagement.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_useraccessmanagement_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.actor import (
    Actor as ocsf_v_1_3_0_useraccessmanagement_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.api import (
    Api as ocsf_v_1_3_0_useraccessmanagement_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.useraccessmanagement.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_useraccessmanagement_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.useraccessmanagement.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_useraccessmanagement_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_useraccessmanagement_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.object import (
    Object as ocsf_v_1_3_0_useraccessmanagement_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.device import (
    Device as ocsf_v_1_3_0_useraccessmanagement_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.useraccessmanagement.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_useraccessmanagement_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_useraccessmanagement_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_useraccessmanagement_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_useraccessmanagement_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.observable import (
    Observable as ocsf_v_1_3_0_useraccessmanagement_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.osint import (
    Osint as ocsf_v_1_3_0_useraccessmanagement_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_useraccessmanagement_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.useraccessmanagement.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_useraccessmanagement_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_useraccessmanagement_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.useraccessmanagement.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_useraccessmanagement_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.useraccessmanagement.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_useraccessmanagement_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.useraccessmanagement.objects.types.user import (
    User as ocsf_v_1_3_0_useraccessmanagement_objects_types_user_User,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.actor import (
    Actor as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.api import (
    Api as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.object import (
    Object as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.device import (
    Device as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_vulnerabilityfinding_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.finding_info import (
    FindingInfo as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_finding_info_FindingInfo,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.observable import (
    Observable as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.osint import (
    Osint as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.vulnerabilityfinding.objects.types.vulnerability import (
    Vulnerability as ocsf_v_1_3_0_vulnerabilityfinding_objects_types_vulnerability_Vulnerability,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_webresourceaccessactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.http_response import (
    HttpResponse as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_http_response_HttpResponse,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.network_proxy import (
    NetworkProxy as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_proxy_NetworkProxy,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.network_connection_info import (
    NetworkConnectionInfo as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_connection_info_NetworkConnectionInfo,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.tls import (
    Tls as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_tls_Tls,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.network_traffic import (
    NetworkTraffic as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_traffic_NetworkTraffic,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.webresourceaccessactivity.objects.types.web_resource import (
    WebResource as ocsf_v_1_3_0_webresourceaccessactivity_objects_types_web_resource_WebResource,
)
from ...ocsf.v_1_3_0.applicationlifecycle.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_applicationlifecycle_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.actor import (
    Actor as ocsf_v_1_3_0_applicationlifecycle_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.api import (
    Api as ocsf_v_1_3_0_applicationlifecycle_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.product import (
    Product as ocsf_v_1_3_0_applicationlifecycle_objects_types_product_Product,
)
from ...ocsf.v_1_3_0.applicationlifecycle.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_applicationlifecycle_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.applicationlifecycle.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_applicationlifecycle_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_applicationlifecycle_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.object import (
    Object as ocsf_v_1_3_0_applicationlifecycle_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.device import (
    Device as ocsf_v_1_3_0_applicationlifecycle_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.applicationlifecycle.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_applicationlifecycle_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_applicationlifecycle_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_applicationlifecycle_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.observable import (
    Observable as ocsf_v_1_3_0_applicationlifecycle_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.applicationlifecycle.objects.types.osint import (
    Osint as ocsf_v_1_3_0_applicationlifecycle_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.applicationlifecycle.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_applicationlifecycle_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.applicationlifecycle.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_applicationlifecycle_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.applicationlifecycle.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_applicationlifecycle_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_6_0_filehostingactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_6_0_filehostingactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.actor import (
    Actor as ocsf_v_1_6_0_filehostingactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.api import (
    Api as ocsf_v_1_6_0_filehostingactivity_objects_types_api_Api,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.attack import (
    Attack as ocsf_v_1_6_0_filehostingactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_6_0_filehostingactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_6_0_filehostingactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_6_0_filehostingactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_6_0_filehostingactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_6_0_filehostingactivity_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.network_connection_info import (
    NetworkConnectionInfo as ocsf_v_1_6_0_filehostingactivity_objects_types_network_connection_info_NetworkConnectionInfo,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.object import (
    Object as ocsf_v_1_6_0_filehostingactivity_objects_types_object_Object,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.device import (
    Device as ocsf_v_1_6_0_filehostingactivity_objects_types_device_Device,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_6_0_filehostingactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_6_0_filehostingactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_6_0.filehostingactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_6_0_filehostingactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_6_0_filehostingactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.file import (
    File as ocsf_v_1_6_0_filehostingactivity_objects_types_file_File,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_6_0_filehostingactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_6_0_filehostingactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.http_response import (
    HttpResponse as ocsf_v_1_6_0_filehostingactivity_objects_types_http_response_HttpResponse,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.malware import (
    Malware as ocsf_v_1_6_0_filehostingactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.malware_scan_info import (
    MalwareScanInfo as ocsf_v_1_6_0_filehostingactivity_objects_types_malware_scan_info_MalwareScanInfo,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_6_0_filehostingactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.observable import (
    Observable as ocsf_v_1_6_0_filehostingactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.osint import (
    Osint as ocsf_v_1_6_0_filehostingactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.policy import (
    Policy as ocsf_v_1_6_0_filehostingactivity_objects_types_policy_Policy,
)
from ...ocsf.v_1_6_0.filehostingactivity.objects.types.fingerprint import (
    Fingerprint as ocsf_v_1_6_0_filehostingactivity_objects_types_fingerprint_Fingerprint,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_6_0_filehostingactivity_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_6_0_filehostingactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.share_type_id import ShareTypeId
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_6_0_filehostingactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_6_0.filehostingactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_6_0_filehostingactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.action_id import (
    ActionId as ocsf_v_1_6_0_emailactivity_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_6_0_emailactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.actor import (
    Actor as ocsf_v_1_6_0_emailactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.api import (
    Api as ocsf_v_1_6_0_emailactivity_objects_types_api_Api,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.attack import (
    Attack as ocsf_v_1_6_0_emailactivity_objects_types_attack_Attack,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.authorization import (
    Authorization as ocsf_v_1_6_0_emailactivity_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_6_0_emailactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_6_0_emailactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_6_0_emailactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_6_0_emailactivity_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.object import (
    Object as ocsf_v_1_6_0_emailactivity_objects_types_object_Object,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.device import (
    Device as ocsf_v_1_6_0_emailactivity_objects_types_device_Device,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.direction_id import DirectionId
from ...ocsf.v_1_6_0.emailactivity.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_6_0_emailactivity_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_6_0_emailactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.email import (
    Email as ocsf_v_1_6_0_emailactivity_objects_types_email_Email,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.email_auth import EmailAuth
from ...ocsf.v_1_6_0.emailactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_6_0_emailactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_6_0_emailactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_6_0_emailactivity_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_6_0.emailactivity.base.types.email_address import EmailAddress
from ...ocsf.v_1_6_0.emailactivity.objects.types.malware import (
    Malware as ocsf_v_1_6_0_emailactivity_objects_types_malware_Malware,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.malware_scan_info import (
    MalwareScanInfo as ocsf_v_1_6_0_emailactivity_objects_types_malware_scan_info_MalwareScanInfo,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_6_0_emailactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.observable import (
    Observable as ocsf_v_1_6_0_emailactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.osint import (
    Osint as ocsf_v_1_6_0_emailactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.policy import (
    Policy as ocsf_v_1_6_0_emailactivity_objects_types_policy_Policy,
)
from ...ocsf.v_1_6_0.emailactivity.objects.types.fingerprint import (
    Fingerprint as ocsf_v_1_6_0_emailactivity_objects_types_fingerprint_Fingerprint,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_6_0_emailactivity_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_6_0_emailactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_6_0_emailactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_6_0.emailactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_6_0_emailactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.cloudactivity.classes.types.activity_id import (
    ActivityId as ocsf_v_1_3_0_cloudactivity_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.actor import (
    Actor as ocsf_v_1_3_0_cloudactivity_objects_types_actor_Actor,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.api import (
    Api as ocsf_v_1_3_0_cloudactivity_objects_types_api_Api,
)
from ...ocsf.v_1_3_0.cloudactivity.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_3_0_cloudactivity_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_3_0.cloudactivity.classes.types.class_uid import (
    ClassUid as ocsf_v_1_3_0_cloudactivity_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.cloud import (
    Cloud as ocsf_v_1_3_0_cloudactivity_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.object import (
    Object as ocsf_v_1_3_0_cloudactivity_objects_types_object_Object,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.device import (
    Device as ocsf_v_1_3_0_cloudactivity_objects_types_device_Device,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.network_endpoint import (
    NetworkEndpoint as ocsf_v_1_3_0_cloudactivity_objects_types_network_endpoint_NetworkEndpoint,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.email import (
    Email as ocsf_v_1_3_0_cloudactivity_objects_types_email_Email,
)
from ...ocsf.v_1_3_0.cloudactivity.base.types.timestamp import (
    Timestamp as ocsf_v_1_3_0_cloudactivity_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.enrichment import (
    Enrichment as ocsf_v_1_3_0_cloudactivity_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.file import (
    File as ocsf_v_1_3_0_cloudactivity_objects_types_file_File,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.http_request import (
    HttpRequest as ocsf_v_1_3_0_cloudactivity_objects_types_http_request_HttpRequest,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.http_response import (
    HttpResponse as ocsf_v_1_3_0_cloudactivity_objects_types_http_response_HttpResponse,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.meeting import Meeting
from ...ocsf.v_1_3_0.cloudactivity.objects.types.messaging import Messaging
from ...ocsf.v_1_3_0.cloudactivity.objects.types.metadata import (
    Metadata as ocsf_v_1_3_0_cloudactivity_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.observable import (
    Observable as ocsf_v_1_3_0_cloudactivity_objects_types_observable_Observable,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.osint import (
    Osint as ocsf_v_1_3_0_cloudactivity_objects_types_osint_Osint,
)
from ...ocsf.v_1_3_0.cloudactivity.classes.types.severity_id import (
    SeverityId as ocsf_v_1_3_0_cloudactivity_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.sharing import Sharing
from ...ocsf.v_1_3_0.cloudactivity.objects.types.product import (
    Product as ocsf_v_1_3_0_cloudactivity_objects_types_product_Product,
)
from ...ocsf.v_1_3_0.cloudactivity.classes.types.status_id import (
    StatusId as ocsf_v_1_3_0_cloudactivity_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.tls import (
    Tls as ocsf_v_1_3_0_cloudactivity_objects_types_tls_Tls,
)
from ...ocsf.v_1_3_0.cloudactivity.classes.types.type_uid import (
    TypeUid as ocsf_v_1_3_0_cloudactivity_classes_types_type_uid_TypeUid,
)
from ...ocsf.v_1_3_0.cloudactivity.objects.types.web_resource import (
    WebResource as ocsf_v_1_3_0_cloudactivity_objects_types_web_resource_WebResource,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.action_id import (
    ActionId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_action_id_ActionId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.activity_id import (
    ActivityId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_activity_id_ActivityId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.actor import (
    Actor as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_actor_Actor,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.api import (
    Api as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_api_Api,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.attack import (
    Attack as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_attack_Attack,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.authorization import (
    Authorization as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_authorization_Authorization,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.category_uid import (
    CategoryUid as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_category_uid_CategoryUid,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.class_uid import (
    ClassUid as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_class_uid_ClassUid,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.cloud import (
    Cloud as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_cloud_Cloud,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.confidence_id import (
    ConfidenceId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_confidence_id_ConfidenceId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.container import (
    Container,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.object import (
    Object as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_object_Object,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.database import Database
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.databucket import (
    Databucket,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.device import (
    Device as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_device_Device,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.disposition_id import (
    DispositionId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_disposition_id_DispositionId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.base.types.timestamp import (
    Timestamp as ocsf_v_1_4_0_cloudresourcesinventoryinfo_base_types_timestamp_Timestamp,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.enrichment import (
    Enrichment as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_enrichment_Enrichment,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.firewall_rule import (
    FirewallRule as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_firewall_rule_FirewallRule,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.idp import Idp
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.malware import (
    Malware as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_malware_Malware,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.metadata import (
    Metadata as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_metadata_Metadata,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.observable import (
    Observable as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_observable_Observable,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.osint import (
    Osint as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_osint_Osint,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.policy import (
    Policy as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_policy_Policy,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.resource_details import (
    ResourceDetails as ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_resource_details_ResourceDetails,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.risk_level_id import (
    RiskLevelId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_risk_level_id_RiskLevelId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.severity_id import (
    SeverityId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_severity_id_SeverityId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.status_id import (
    StatusId as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_status_id_StatusId,
)
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.objects.types.table import Table
from ...ocsf.v_1_4_0.cloudresourcesinventoryinfo.classes.types.type_uid import (
    TypeUid as ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_type_uid_TypeUid,
)
import typing_extensions
from ...core.unchecked_base_model import UnionMetadata


class Event_AccountChange(UncheckedBaseModel):
    class_name: typing.Literal["Account Change"] = "Account Change"
    activity_id: ocsf_v_1_3_0_accountchange_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_accountchange_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_3_0_accountchange_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_accountchange_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_accountchange_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_accountchange_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_accountchange_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_3_0_accountchange_objects_types_device_Device] = (
        None
    )
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_accountchange_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_accountchange_objects_types_enrichment_Enrichment]
    ] = None
    http_request: typing.Optional[
        ocsf_v_1_3_0_accountchange_objects_types_http_request_HttpRequest
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_accountchange_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_accountchange_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_accountchange_objects_types_osint_Osint]
    ] = None
    policy: typing.Optional[ocsf_v_1_3_0_accountchange_objects_types_policy_Policy] = (
        None
    )
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_accountchange_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_accountchange_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_accountchange_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_accountchange_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_accountchange_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_accountchange_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_accountchange_objects_types_object_Object
    ] = None
    user: ocsf_v_1_3_0_accountchange_objects_types_user_User
    user_result: typing.Optional[ocsf_v_1_3_0_accountchange_objects_types_user_User] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ApiActivity(UncheckedBaseModel):
    class_name: typing.Literal["API Activity"] = "API Activity"
    activity_id: ocsf_v_1_3_0_apiactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: ocsf_v_1_3_0_apiactivity_objects_types_actor_Actor
    api: typing.Optional[ocsf_v_1_3_0_apiactivity_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_apiactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_apiactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_apiactivity_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_apiactivity_objects_types_object_Object
    ] = None
    dst_endpoint: typing.Optional[
        ocsf_v_1_3_0_apiactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_apiactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_apiactivity_objects_types_enrichment_Enrichment]
    ] = None
    http_request: typing.Optional[
        ocsf_v_1_3_0_apiactivity_objects_types_http_request_HttpRequest
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_apiactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_apiactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_apiactivity_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_apiactivity_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_apiactivity_classes_types_severity_id_SeverityId
    src_endpoint: (
        ocsf_v_1_3_0_apiactivity_objects_types_network_endpoint_NetworkEndpoint
    )
    start_time: typing.Optional[
        ocsf_v_1_3_0_apiactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_apiactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_apiactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_apiactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_3_0_apiactivity_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ApplicationSecurityPostureFinding(UncheckedBaseModel):
    class_name: typing.Literal["Application Security Posture Finding"] = (
        "Application Security Posture Finding"
    )
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_actor_Actor
    ] = None
    api: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_api_Api
    ] = None
    application: typing.Optional[Application] = None
    attacks: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_attack_Attack
        ]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_category_uid_CategoryUid
    class_uid: (
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_class_uid_ClassUid
    )
    cloud: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_cloud_Cloud
    ] = None
    comment: typing.Optional[str] = None
    compliance: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_compliance_Compliance
    ] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_device_Device
    ] = None
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_enrichment_Enrichment
        ]
    ] = None
    finding_info: ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_finding_info_FindingInfo
    firewall_rule: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_firewall_rule_FirewallRule
    ] = None
    is_alert: typing.Optional[bool] = None
    malware: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_malware_Malware
        ]
    ] = None
    malware_scan_info: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_malware_scan_info_MalwareScanInfo
    ] = None
    message: typing.Optional[str] = None
    metadata: (
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_metadata_Metadata
    )
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_osint_Osint
        ]
    ] = None
    policy: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_policy_Policy
    ] = None
    raw_data: typing.Optional[str] = None
    raw_data_size: typing.Optional[int] = None
    remediation: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_remediation_Remediation
    ] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    risk_details: typing.Optional[str] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_5_0_applicationsecurityposturefinding_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: (
        ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_type_uid_TypeUid
    )
    unmapped: typing.Optional[
        ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_object_Object
    ] = None
    vendor_attributes: typing.Optional[VendorAttributes] = None
    vulnerabilities: typing.Optional[
        typing.List[
            ocsf_v_1_5_0_applicationsecurityposturefinding_objects_types_vulnerability_Vulnerability
        ]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_EntityManagement(UncheckedBaseModel):
    class_name: typing.Literal["Entity Management"] = "Entity Management"
    access_list: typing.Optional[typing.List[str]] = None
    access_mask: typing.Optional[int] = None
    activity_id: ocsf_v_1_3_0_entitymanagement_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_entitymanagement_objects_types_actor_Actor] = (
        None
    )
    api: typing.Optional[ocsf_v_1_3_0_entitymanagement_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_entitymanagement_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_entitymanagement_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_entitymanagement_objects_types_cloud_Cloud] = (
        None
    )
    comment: typing.Optional[str] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_entitymanagement_objects_types_enrichment_Enrichment]
    ] = None
    entity: ManagedEntity
    entity_result: typing.Optional[ManagedEntity] = None
    http_request: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_objects_types_http_request_HttpRequest
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_entitymanagement_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_entitymanagement_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_entitymanagement_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_entitymanagement_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_entitymanagement_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_entitymanagement_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_entitymanagement_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_Authentication(UncheckedBaseModel):
    class_name: typing.Literal["Authentication"] = "Authentication"
    activity_id: ocsf_v_1_3_0_authentication_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_authentication_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_3_0_authentication_objects_types_api_Api] = None
    auth_factors: typing.Optional[typing.List[AuthFactor]] = None
    auth_protocol: typing.Optional[str] = None
    auth_protocol_id: typing.Optional[AuthProtocolId] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_authentication_classes_types_category_uid_CategoryUid
    certificate: typing.Optional[Certificate] = None
    class_uid: ocsf_v_1_3_0_authentication_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_authentication_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_3_0_authentication_objects_types_device_Device] = (
        None
    )
    dst_endpoint: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_authentication_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_authentication_objects_types_enrichment_Enrichment]
    ] = None
    http_request: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_http_request_HttpRequest
    ] = None
    is_cleartext: typing.Optional[bool] = None
    is_mfa: typing.Optional[bool] = None
    is_new_logon: typing.Optional[bool] = None
    is_remote: typing.Optional[bool] = None
    logon_process: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_process_Process
    ] = None
    logon_type: typing.Optional[str] = None
    logon_type_id: typing.Optional[LogonTypeId] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_authentication_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_authentication_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_authentication_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    service: typing.Optional[Service] = None
    session: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_session_Session
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_authentication_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_authentication_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_authentication_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_authentication_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_authentication_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_authentication_objects_types_object_Object
    ] = None
    user: ocsf_v_1_3_0_authentication_objects_types_user_User

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_AuthorizeSession(UncheckedBaseModel):
    class_name: typing.Literal["Authorize Session"] = "Authorize Session"
    activity_id: ocsf_v_1_3_0_authorizesession_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_authorizesession_objects_types_actor_Actor] = (
        None
    )
    api: typing.Optional[ocsf_v_1_3_0_authorizesession_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_authorizesession_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_authorizesession_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_authorizesession_objects_types_cloud_Cloud] = (
        None
    )
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_device_Device
    ] = None
    dst_endpoint: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_authorizesession_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_authorizesession_objects_types_enrichment_Enrichment]
    ] = None
    group: typing.Optional[ocsf_v_1_3_0_authorizesession_objects_types_group_Group] = (
        None
    )
    http_request: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_http_request_HttpRequest
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_authorizesession_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_authorizesession_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_authorizesession_objects_types_osint_Osint]
    ] = None
    privileges: typing.Optional[typing.List[str]] = None
    raw_data: typing.Optional[str] = None
    session: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_session_Session
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_authorizesession_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_authorizesession_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_authorizesession_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_authorizesession_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_authorizesession_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_authorizesession_objects_types_object_Object
    ] = None
    user: ocsf_v_1_3_0_authorizesession_objects_types_user_User

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_BaseEvent(UncheckedBaseModel):
    class_name: typing.Literal["Base Event"] = "Base Event"
    activity_id: ocsf_v_1_3_0_baseevent_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    api: typing.Optional[ocsf_v_1_3_0_baseevent_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_baseevent_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_baseevent_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_baseevent_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_baseevent_objects_types_object_Object
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[ocsf_v_1_3_0_baseevent_base_types_timestamp_Timestamp] = (
        None
    )
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_baseevent_objects_types_enrichment_Enrichment]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_baseevent_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_baseevent_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_baseevent_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_baseevent_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_baseevent_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_baseevent_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_baseevent_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: int
    unmapped: typing.Optional[ocsf_v_1_3_0_baseevent_objects_types_object_Object] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ComplianceFinding(UncheckedBaseModel):
    class_name: typing.Literal["Compliance Finding"] = "Compliance Finding"
    activity_id: ocsf_v_1_3_0_compliancefinding_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_compliancefinding_objects_types_actor_Actor] = (
        None
    )
    api: typing.Optional[ocsf_v_1_3_0_compliancefinding_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_compliancefinding_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_compliancefinding_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_compliancefinding_objects_types_cloud_Cloud] = (
        None
    )
    comment: typing.Optional[str] = None
    compliance: ocsf_v_1_3_0_compliancefinding_objects_types_compliance_Compliance
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_compliancefinding_objects_types_enrichment_Enrichment]
    ] = None
    finding_info: ocsf_v_1_3_0_compliancefinding_objects_types_finding_info_FindingInfo
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_compliancefinding_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_compliancefinding_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_compliancefinding_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    remediation: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_objects_types_remediation_Remediation
    ] = None
    resource: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_objects_types_resource_details_ResourceDetails
    ] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_compliancefinding_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_compliancefinding_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_compliancefinding_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_compliancefinding_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_compliancefinding_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_DeviceConfigState(UncheckedBaseModel):
    class_name: typing.Literal["Device Config State"] = "Device Config State"
    activity_id: ocsf_v_1_3_0_configstate_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_configstate_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_3_0_configstate_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_configstate_classes_types_category_uid_CategoryUid
    cis_benchmark_result: typing.Optional[CisBenchmarkResult] = None
    class_uid: ocsf_v_1_3_0_configstate_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_configstate_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_configstate_objects_types_object_Object
    ] = None
    device: ocsf_v_1_3_0_configstate_objects_types_device_Device
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_configstate_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_configstate_objects_types_enrichment_Enrichment]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_configstate_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_configstate_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_configstate_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_configstate_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_configstate_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_configstate_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_configstate_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_configstate_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_3_0_configstate_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_DetectionFinding(UncheckedBaseModel):
    class_name: typing.Literal["Detection Finding"] = "Detection Finding"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_detectionfinding_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_detectionfinding_objects_types_actor_Actor] = (
        None
    )
    api: typing.Optional[ocsf_v_1_3_0_detectionfinding_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_detectionfinding_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_detectionfinding_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_detectionfinding_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_detectionfinding_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_detectionfinding_objects_types_cloud_Cloud] = (
        None
    )
    comment: typing.Optional[str] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_objects_types_device_Device
    ] = None
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_detectionfinding_objects_types_enrichment_Enrichment]
    ] = None
    evidences: typing.Optional[typing.List[Evidences]] = None
    finding_info: ocsf_v_1_3_0_detectionfinding_objects_types_finding_info_FindingInfo
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_objects_types_firewall_rule_FirewallRule
    ] = None
    impact: typing.Optional[str] = None
    impact_id: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_classes_types_impact_id_ImpactId
    ] = None
    impact_score: typing.Optional[int] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_detectionfinding_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_detectionfinding_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_detectionfinding_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_detectionfinding_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    remediation: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_objects_types_remediation_Remediation
    ] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_detectionfinding_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    risk_details: typing.Optional[str] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_detectionfinding_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_detectionfinding_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_detectionfinding_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_detectionfinding_objects_types_object_Object
    ] = None
    vulnerabilities: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_detectionfinding_objects_types_vulnerability_Vulnerability
        ]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_DnsActivity(UncheckedBaseModel):
    class_name: typing.Literal["DNS Activity"] = "DNS Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_dnsactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_actor_Actor] = None
    answers: typing.Optional[typing.List[DnsAnswer]] = None
    api: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_api_Api] = None
    app_name: typing.Optional[str] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_dnsactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[ocsf_v_1_3_0_dnsactivity_objects_types_authorization_Authorization]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_dnsactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_dnsactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_cloud_Cloud] = None
    connection_info: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_device_Device] = None
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_classes_types_disposition_id_DispositionId
    ] = None
    dst_endpoint: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_dnsactivity_objects_types_enrichment_Enrichment]
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    ja_4_fingerprint_list: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_dnsactivity_objects_types_ja_4_fingerprint_Ja4Fingerprint
        ]
    ] = pydantic.Field(alias="ja4_fingerprint_list", default=None)
    load_balancer: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_load_balancer_LoadBalancer
    ] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_dnsactivity_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_dnsactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_dnsactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_dnsactivity_objects_types_osint_Osint]
    ] = None
    proxy: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_connection_info: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    proxy_endpoint: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_http_request: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_http_request_HttpRequest
    ] = None
    proxy_http_response: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_http_response_HttpResponse
    ] = None
    proxy_tls: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_tls_Tls] = None
    proxy_traffic: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    query: typing.Optional[DnsQuery] = None
    query_time: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_base_types_timestamp_Timestamp
    ] = None
    query_time_dt: typing.Optional[dt.datetime] = None
    raw_data: typing.Optional[str] = None
    rcode: typing.Optional[str] = None
    rcode_id: typing.Optional[RcodeId] = None
    response_time: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_base_types_timestamp_Timestamp
    ] = None
    response_time_dt: typing.Optional[dt.datetime] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_dnsactivity_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_dnsactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    tls: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_tls_Tls] = None
    traffic: typing.Optional[
        ocsf_v_1_3_0_dnsactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_dnsactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_3_0_dnsactivity_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_HttpActivity(UncheckedBaseModel):
    class_name: typing.Literal["HTTP Activity"] = "HTTP Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_6_0_httpactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_6_0_httpactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_api_Api] = None
    app_name: typing.Optional[str] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_6_0_httpactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[ocsf_v_1_6_0_httpactivity_objects_types_authorization_Authorization]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_6_0_httpactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_6_0_httpactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_cloud_Cloud] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_6_0_httpactivity_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    connection_info: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_device_Device] = (
        None
    )
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_6_0_httpactivity_classes_types_disposition_id_DispositionId
    ] = None
    dst_endpoint: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_6_0_httpactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_6_0_httpactivity_objects_types_enrichment_Enrichment]
    ] = None
    file: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_file_File] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    http_cookies: typing.Optional[typing.List[HttpCookie]] = None
    http_request: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_http_request_HttpRequest
    ] = None
    http_response: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_http_response_HttpResponse
    ] = None
    http_status: typing.Optional[int] = None
    is_alert: typing.Optional[bool] = None
    ja_4_fingerprint_list: typing.Optional[
        typing.List[
            ocsf_v_1_6_0_httpactivity_objects_types_ja_4_fingerprint_Ja4Fingerprint
        ]
    ] = pydantic.Field(alias="ja4_fingerprint_list", default=None)
    load_balancer: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_load_balancer_LoadBalancer
    ] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_6_0_httpactivity_objects_types_malware_Malware]
    ] = None
    malware_scan_info: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_malware_scan_info_MalwareScanInfo
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_6_0_httpactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_6_0_httpactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_6_0_httpactivity_objects_types_osint_Osint]
    ] = None
    policy: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_policy_Policy] = (
        None
    )
    proxy: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_connection_info: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    proxy_endpoint: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_http_request: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_http_request_HttpRequest
    ] = None
    proxy_http_response: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_http_response_HttpResponse
    ] = None
    proxy_tls: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_tls_Tls] = None
    proxy_traffic: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    raw_data: typing.Optional[str] = None
    raw_data_hash: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_fingerprint_Fingerprint
    ] = None
    raw_data_size: typing.Optional[int] = None
    risk_details: typing.Optional[str] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_6_0_httpactivity_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_6_0_httpactivity_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_6_0_httpactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_6_0_httpactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_6_0_httpactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    tls: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_tls_Tls] = None
    traffic: typing.Optional[
        ocsf_v_1_6_0_httpactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_6_0_httpactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_6_0_httpactivity_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_FileSystemActivity(UncheckedBaseModel):
    class_name: typing.Literal["File System Activity"] = "File System Activity"
    access_mask: typing.Optional[int] = None
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_fileactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_fileactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: ocsf_v_1_3_0_fileactivity_objects_types_actor_Actor
    api: typing.Optional[ocsf_v_1_3_0_fileactivity_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_fileactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[ocsf_v_1_3_0_fileactivity_objects_types_authorization_Authorization]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_fileactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_fileactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_fileactivity_objects_types_cloud_Cloud] = None
    component: typing.Optional[str] = None
    connection_uid: typing.Optional[str] = None
    count: typing.Optional[int] = None
    create_mask: typing.Optional[str] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_fileactivity_objects_types_object_Object
    ] = None
    device: ocsf_v_1_3_0_fileactivity_objects_types_device_Device
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_fileactivity_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_fileactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_fileactivity_objects_types_enrichment_Enrichment]
    ] = None
    file: ocsf_v_1_3_0_fileactivity_objects_types_file_File
    file_diff: typing.Optional[str] = None
    file_result: typing.Optional[ocsf_v_1_3_0_fileactivity_objects_types_file_File] = (
        None
    )
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_fileactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_fileactivity_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_fileactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_fileactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_fileactivity_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_fileactivity_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_fileactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_fileactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_fileactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_fileactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_3_0_fileactivity_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_GroupManagement(UncheckedBaseModel):
    class_name: typing.Literal["Group Management"] = "Group Management"
    activity_id: ocsf_v_1_3_0_groupmanagement_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_groupmanagement_objects_types_actor_Actor] = (
        None
    )
    api: typing.Optional[ocsf_v_1_3_0_groupmanagement_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_groupmanagement_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_groupmanagement_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_groupmanagement_objects_types_cloud_Cloud] = (
        None
    )
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_groupmanagement_objects_types_enrichment_Enrichment]
    ] = None
    group: ocsf_v_1_3_0_groupmanagement_objects_types_group_Group
    http_request: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_objects_types_http_request_HttpRequest
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_groupmanagement_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_groupmanagement_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_groupmanagement_objects_types_osint_Osint]
    ] = None
    privileges: typing.Optional[typing.List[str]] = None
    raw_data: typing.Optional[str] = None
    resource: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_objects_types_resource_details_ResourceDetails
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_groupmanagement_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_groupmanagement_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_groupmanagement_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_groupmanagement_objects_types_object_Object
    ] = None
    user: typing.Optional[ocsf_v_1_3_0_groupmanagement_objects_types_user_User] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_IncidentFinding(UncheckedBaseModel):
    class_name: typing.Literal["Incident Finding"] = "Incident Finding"
    activity_id: ocsf_v_1_3_0_incidentfinding_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    api: typing.Optional[ocsf_v_1_3_0_incidentfinding_objects_types_api_Api] = None
    assignee: typing.Optional[ocsf_v_1_3_0_incidentfinding_objects_types_user_User] = (
        None
    )
    assignee_group: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_objects_types_group_Group
    ] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_incidentfinding_objects_types_attack_Attack]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_incidentfinding_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_incidentfinding_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_incidentfinding_objects_types_cloud_Cloud] = (
        None
    )
    comment: typing.Optional[str] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_objects_types_object_Object
    ] = None
    desc: typing.Optional[str] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_incidentfinding_objects_types_enrichment_Enrichment]
    ] = None
    finding_info_list: typing.List[
        ocsf_v_1_3_0_incidentfinding_objects_types_finding_info_FindingInfo
    ]
    impact: typing.Optional[str] = None
    impact_id: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_classes_types_impact_id_ImpactId
    ] = None
    impact_score: typing.Optional[int] = None
    is_suspected_breach: typing.Optional[bool] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_incidentfinding_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_incidentfinding_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_incidentfinding_objects_types_osint_Osint]
    ] = None
    priority: typing.Optional[str] = None
    priority_id: typing.Optional[PriorityId] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_incidentfinding_classes_types_severity_id_SeverityId
    src_url: typing.Optional[UrlString] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: ocsf_v_1_3_0_incidentfinding_classes_types_status_id_StatusId
    ticket: typing.Optional[Ticket] = None
    time: ocsf_v_1_3_0_incidentfinding_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_incidentfinding_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_incidentfinding_objects_types_object_Object
    ] = None
    verdict: typing.Optional[str] = None
    verdict_id: typing.Optional[VerdictId] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_DeviceInventoryInfo(UncheckedBaseModel):
    class_name: typing.Literal["Device Inventory Info"] = "Device Inventory Info"
    activity_id: ocsf_v_1_3_0_inventoryinfo_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_inventoryinfo_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_3_0_inventoryinfo_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_inventoryinfo_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_inventoryinfo_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_inventoryinfo_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_inventoryinfo_objects_types_object_Object
    ] = None
    device: ocsf_v_1_3_0_inventoryinfo_objects_types_device_Device
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_inventoryinfo_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_inventoryinfo_objects_types_enrichment_Enrichment]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_inventoryinfo_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_inventoryinfo_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_inventoryinfo_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_inventoryinfo_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_inventoryinfo_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_inventoryinfo_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_inventoryinfo_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_inventoryinfo_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_inventoryinfo_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ModuleActivity(UncheckedBaseModel):
    class_name: typing.Literal["Module Activity"] = "Module Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_moduleactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: ocsf_v_1_3_0_moduleactivity_objects_types_actor_Actor
    api: typing.Optional[ocsf_v_1_3_0_moduleactivity_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_moduleactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_moduleactivity_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_moduleactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_moduleactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_moduleactivity_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_objects_types_object_Object
    ] = None
    device: ocsf_v_1_3_0_moduleactivity_objects_types_device_Device
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_moduleactivity_objects_types_enrichment_Enrichment]
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_moduleactivity_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_moduleactivity_objects_types_metadata_Metadata
    module: ocsf_v_1_3_0_moduleactivity_objects_types_module_Module
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_moduleactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_moduleactivity_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_moduleactivity_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_moduleactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_moduleactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_moduleactivity_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_NetworkActivity(UncheckedBaseModel):
    class_name: typing.Literal["Network Activity"] = "Network Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_networkactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_networkactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_networkactivity_objects_types_actor_Actor] = (
        None
    )
    api: typing.Optional[ocsf_v_1_3_0_networkactivity_objects_types_api_Api] = None
    app_name: typing.Optional[str] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_networkactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_networkactivity_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_networkactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_networkactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_networkactivity_objects_types_cloud_Cloud] = (
        None
    )
    connection_info: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_device_Device
    ] = None
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_networkactivity_classes_types_disposition_id_DispositionId
    ] = None
    dst_endpoint: (
        ocsf_v_1_3_0_networkactivity_objects_types_network_endpoint_NetworkEndpoint
    )
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_networkactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_networkactivity_objects_types_enrichment_Enrichment]
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    ja_4_fingerprint_list: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_networkactivity_objects_types_ja_4_fingerprint_Ja4Fingerprint
        ]
    ] = pydantic.Field(alias="ja4_fingerprint_list", default=None)
    load_balancer: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_load_balancer_LoadBalancer
    ] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_networkactivity_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_networkactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_networkactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_networkactivity_objects_types_osint_Osint]
    ] = None
    proxy: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_connection_info: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    proxy_endpoint: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_http_request: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_http_request_HttpRequest
    ] = None
    proxy_http_response: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_http_response_HttpResponse
    ] = None
    proxy_tls: typing.Optional[ocsf_v_1_3_0_networkactivity_objects_types_tls_Tls] = (
        None
    )
    proxy_traffic: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_networkactivity_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_networkactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_networkactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_networkactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    tls: typing.Optional[ocsf_v_1_3_0_networkactivity_objects_types_tls_Tls] = None
    traffic: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_networkactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_networkactivity_objects_types_object_Object
    ] = None
    url: typing.Optional[Url] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ProcessActivity(UncheckedBaseModel):
    class_name: typing.Literal["Process Activity"] = "Process Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_processactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_processactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: ocsf_v_1_3_0_processactivity_objects_types_actor_Actor
    actual_permissions: typing.Optional[int] = None
    api: typing.Optional[ocsf_v_1_3_0_processactivity_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_processactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_processactivity_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_processactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_processactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_processactivity_objects_types_cloud_Cloud] = (
        None
    )
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_processactivity_objects_types_object_Object
    ] = None
    device: ocsf_v_1_3_0_processactivity_objects_types_device_Device
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_processactivity_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_processactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_processactivity_objects_types_enrichment_Enrichment]
    ] = None
    exit_code: typing.Optional[int] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_processactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    injection_type: typing.Optional[str] = None
    injection_type_id: typing.Optional[InjectionTypeId] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_processactivity_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_processactivity_objects_types_metadata_Metadata
    module: typing.Optional[
        ocsf_v_1_3_0_processactivity_objects_types_module_Module
    ] = None
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_processactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_processactivity_objects_types_osint_Osint]
    ] = None
    process: ocsf_v_1_3_0_processactivity_objects_types_process_Process
    raw_data: typing.Optional[str] = None
    requested_permissions: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_processactivity_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_processactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_processactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_processactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_processactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_processactivity_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ScanActivity(UncheckedBaseModel):
    class_name: typing.Literal["Scan Activity"] = "Scan Activity"
    activity_id: ocsf_v_1_3_0_scanactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_scanactivity_objects_types_actor_Actor] = None
    agent_list: typing.Optional[typing.List[Agent]] = None
    api: typing.Optional[ocsf_v_1_3_0_scanactivity_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_scanactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_scanactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_scanactivity_objects_types_cloud_Cloud] = None
    command_uid: typing.Optional[str] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_scanactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_3_0_scanactivity_objects_types_device_Device] = (
        None
    )
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_scanactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_scanactivity_objects_types_enrichment_Enrichment]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_scanactivity_objects_types_metadata_Metadata
    num_detections: typing.Optional[int] = None
    num_files: typing.Optional[int] = None
    num_folders: typing.Optional[int] = None
    num_hosts: typing.Optional[int] = None
    num_network_items: typing.Optional[int] = None
    num_processes: typing.Optional[int] = None
    num_registry_items: typing.Optional[int] = None
    num_resolutions: typing.Optional[int] = None
    num_skipped_items: typing.Optional[int] = None
    num_trusted_items: typing.Optional[int] = None
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_scanactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_scanactivity_objects_types_osint_Osint]
    ] = None
    policy: typing.Optional[ocsf_v_1_3_0_scanactivity_objects_types_policy_Policy] = (
        None
    )
    raw_data: typing.Optional[str] = None
    scan: Scan
    schedule_uid: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_scanactivity_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_scanactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_scanactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_scanactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    total: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_scanactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_3_0_scanactivity_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ScheduledJobActivity(UncheckedBaseModel):
    class_name: typing.Literal["Scheduled Job Activity"] = "Scheduled Job Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_3_0_scheduledjobactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_objects_types_actor_Actor
    ] = None
    api: typing.Optional[ocsf_v_1_3_0_scheduledjobactivity_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_scheduledjobactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_scheduledjobactivity_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_3_0_scheduledjobactivity_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_3_0_scheduledjobactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_objects_types_cloud_Cloud
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_objects_types_object_Object
    ] = None
    device: ocsf_v_1_3_0_scheduledjobactivity_objects_types_device_Device
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_scheduledjobactivity_objects_types_enrichment_Enrichment
        ]
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    job: Job
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_scheduledjobactivity_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_scheduledjobactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_scheduledjobactivity_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_scheduledjobactivity_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_scheduledjobactivity_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_scheduledjobactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_scheduledjobactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_scheduledjobactivity_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_SecurityFinding(UncheckedBaseModel):
    class_name: typing.Literal["Security Finding"] = "Security Finding"
    activity_id: ocsf_v_1_3_0_securityfinding_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    analytic: typing.Optional[Analytic] = None
    api: typing.Optional[ocsf_v_1_3_0_securityfinding_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_3_0_securityfinding_objects_types_attack_Attack]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_securityfinding_classes_types_category_uid_CategoryUid
    cis_csc: typing.Optional[typing.List[CisCsc]] = None
    class_uid: ocsf_v_1_3_0_securityfinding_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_securityfinding_objects_types_cloud_Cloud] = (
        None
    )
    compliance: typing.Optional[
        ocsf_v_1_3_0_securityfinding_objects_types_compliance_Compliance
    ] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_3_0_securityfinding_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_securityfinding_objects_types_object_Object
    ] = None
    data_sources: typing.Optional[typing.List[str]] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_securityfinding_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_securityfinding_objects_types_enrichment_Enrichment]
    ] = None
    evidence: typing.Optional[typing.Optional[typing.Any]] = None
    finding: Finding
    impact: typing.Optional[str] = None
    impact_id: typing.Optional[
        ocsf_v_1_3_0_securityfinding_classes_types_impact_id_ImpactId
    ] = None
    impact_score: typing.Optional[int] = None
    kill_chain: typing.Optional[typing.List[KillChainPhase]] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_3_0_securityfinding_objects_types_malware_Malware]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_securityfinding_objects_types_metadata_Metadata
    nist: typing.Optional[typing.List[str]] = None
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_securityfinding_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_securityfinding_objects_types_osint_Osint]
    ] = None
    process: typing.Optional[
        ocsf_v_1_3_0_securityfinding_objects_types_process_Process
    ] = None
    raw_data: typing.Optional[str] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_securityfinding_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_3_0_securityfinding_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_securityfinding_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_securityfinding_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    state: typing.Optional[str] = None
    state_id: StateId
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_securityfinding_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_securityfinding_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_securityfinding_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_securityfinding_objects_types_object_Object
    ] = None
    vulnerabilities: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_securityfinding_objects_types_vulnerability_Vulnerability
        ]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_SoftwareInfo(UncheckedBaseModel):
    class_name: typing.Literal["Software Info"] = "Software Info"
    activity_id: ocsf_v_1_3_0_softwareinfo_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    api: typing.Optional[ocsf_v_1_3_0_softwareinfo_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_softwareinfo_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_softwareinfo_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_softwareinfo_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_softwareinfo_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_3_0_softwareinfo_objects_types_device_Device] = (
        None
    )
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_softwareinfo_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_softwareinfo_objects_types_enrichment_Enrichment]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_softwareinfo_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_softwareinfo_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_softwareinfo_objects_types_osint_Osint]
    ] = None
    product: ocsf_v_1_3_0_softwareinfo_objects_types_product_Product
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_softwareinfo_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_softwareinfo_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_softwareinfo_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_softwareinfo_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_softwareinfo_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[ocsf_v_1_3_0_softwareinfo_objects_types_object_Object] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_UserAccessManagement(UncheckedBaseModel):
    class_name: typing.Literal["User Access Management"] = "User Access Management"
    activity_id: ocsf_v_1_3_0_useraccessmanagement_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_actor_Actor
    ] = None
    api: typing.Optional[ocsf_v_1_3_0_useraccessmanagement_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_3_0_useraccessmanagement_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_3_0_useraccessmanagement_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_cloud_Cloud
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_useraccessmanagement_objects_types_enrichment_Enrichment
        ]
    ] = None
    http_request: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_http_request_HttpRequest
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_useraccessmanagement_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_useraccessmanagement_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_useraccessmanagement_objects_types_osint_Osint]
    ] = None
    privileges: typing.List[str]
    raw_data: typing.Optional[str] = None
    resource: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_resource_details_ResourceDetails
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_useraccessmanagement_classes_types_severity_id_SeverityId
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_useraccessmanagement_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_useraccessmanagement_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_useraccessmanagement_objects_types_object_Object
    ] = None
    user: ocsf_v_1_3_0_useraccessmanagement_objects_types_user_User

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_VulnerabilityFinding(UncheckedBaseModel):
    class_name: typing.Literal["Vulnerability Finding"] = "Vulnerability Finding"
    activity_id: ocsf_v_1_3_0_vulnerabilityfinding_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_actor_Actor
    ] = None
    api: typing.Optional[ocsf_v_1_3_0_vulnerabilityfinding_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_3_0_vulnerabilityfinding_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_3_0_vulnerabilityfinding_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_cloud_Cloud
    ] = None
    comment: typing.Optional[str] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_vulnerabilityfinding_objects_types_enrichment_Enrichment
        ]
    ] = None
    finding_info: (
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_finding_info_FindingInfo
    )
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_vulnerabilityfinding_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_vulnerabilityfinding_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_vulnerabilityfinding_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    resource: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_resource_details_ResourceDetails
    ] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_vulnerabilityfinding_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_vulnerabilityfinding_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_vulnerabilityfinding_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_vulnerabilityfinding_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_object_Object
    ] = None
    vulnerabilities: typing.List[
        ocsf_v_1_3_0_vulnerabilityfinding_objects_types_vulnerability_Vulnerability
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_WebResourceAccessActivity(UncheckedBaseModel):
    class_name: typing.Literal["Web Resource Access Activity"] = (
        "Web Resource Access Activity"
    )
    activity_id: (
        ocsf_v_1_3_0_webresourceaccessactivity_classes_types_activity_id_ActivityId
    )
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_actor_Actor
    ] = None
    api: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_api_Api
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_3_0_webresourceaccessactivity_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_3_0_webresourceaccessactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_cloud_Cloud
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_webresourceaccessactivity_objects_types_enrichment_Enrichment
        ]
    ] = None
    http_request: (
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_http_request_HttpRequest
    )
    http_response: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_http_response_HttpResponse
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_webresourceaccessactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_webresourceaccessactivity_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_webresourceaccessactivity_objects_types_osint_Osint]
    ] = None
    proxy: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_connection_info: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    proxy_endpoint: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_proxy_NetworkProxy
    ] = None
    proxy_http_request: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_http_request_HttpRequest
    ] = None
    proxy_http_response: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_http_response_HttpResponse
    ] = None
    proxy_tls: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_tls_Tls
    ] = None
    proxy_traffic: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_traffic_NetworkTraffic
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: (
        ocsf_v_1_3_0_webresourceaccessactivity_classes_types_severity_id_SeverityId
    )
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_webresourceaccessactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    tls: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_tls_Tls
    ] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_webresourceaccessactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_object_Object
    ] = None
    web_resources: typing.List[
        ocsf_v_1_3_0_webresourceaccessactivity_objects_types_web_resource_WebResource
    ]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_ApplicationLifecycle(UncheckedBaseModel):
    class_name: typing.Literal["Application Lifecycle"] = "Application Lifecycle"
    activity_id: ocsf_v_1_3_0_applicationlifecycle_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_objects_types_actor_Actor
    ] = None
    api: typing.Optional[ocsf_v_1_3_0_applicationlifecycle_objects_types_api_Api] = None
    app: ocsf_v_1_3_0_applicationlifecycle_objects_types_product_Product
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_3_0_applicationlifecycle_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_3_0_applicationlifecycle_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_objects_types_cloud_Cloud
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_objects_types_device_Device
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_applicationlifecycle_objects_types_enrichment_Enrichment
        ]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_3_0_applicationlifecycle_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_3_0_applicationlifecycle_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_applicationlifecycle_objects_types_osint_Osint]
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_applicationlifecycle_classes_types_severity_id_SeverityId
    start_time: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_3_0_applicationlifecycle_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_applicationlifecycle_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_applicationlifecycle_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_FileHostingActivity(UncheckedBaseModel):
    class_name: typing.Literal["File Hosting Activity"] = "File Hosting Activity"
    access_list: typing.Optional[typing.List[str]] = None
    access_mask: typing.Optional[int] = None
    access_result: typing.Optional[typing.Optional[typing.Any]] = None
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_6_0_filehostingactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_actor_Actor
    ] = None
    api: typing.Optional[ocsf_v_1_6_0_filehostingactivity_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_6_0_filehostingactivity_objects_types_attack_Attack]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_6_0_filehostingactivity_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_6_0_filehostingactivity_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_6_0_filehostingactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_cloud_Cloud
    ] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    connection_info: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_network_connection_info_NetworkConnectionInfo
    ] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_device_Device
    ] = None
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_classes_types_disposition_id_DispositionId
    ] = None
    dst_endpoint: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_6_0_filehostingactivity_objects_types_enrichment_Enrichment
        ]
    ] = None
    expiration_time: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_base_types_timestamp_Timestamp
    ] = None
    expiration_time_dt: typing.Optional[dt.datetime] = None
    file: ocsf_v_1_6_0_filehostingactivity_objects_types_file_File
    file_result: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_file_File
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    http_request: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_http_request_HttpRequest
    ] = None
    http_response: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_http_response_HttpResponse
    ] = None
    is_alert: typing.Optional[bool] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_6_0_filehostingactivity_objects_types_malware_Malware]
    ] = None
    malware_scan_info: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_malware_scan_info_MalwareScanInfo
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_6_0_filehostingactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_6_0_filehostingactivity_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_6_0_filehostingactivity_objects_types_osint_Osint]
    ] = None
    policy: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_policy_Policy
    ] = None
    raw_data: typing.Optional[str] = None
    raw_data_hash: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_fingerprint_Fingerprint
    ] = None
    raw_data_size: typing.Optional[int] = None
    risk_details: typing.Optional[str] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_6_0_filehostingactivity_classes_types_severity_id_SeverityId
    share: typing.Optional[str] = None
    share_type: typing.Optional[str] = None
    share_type_id: typing.Optional[ShareTypeId] = None
    src_endpoint: (
        ocsf_v_1_6_0_filehostingactivity_objects_types_network_endpoint_NetworkEndpoint
    )
    start_time: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_6_0_filehostingactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_6_0_filehostingactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_6_0_filehostingactivity_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_EmailActivity(UncheckedBaseModel):
    class_name: typing.Literal["Email Activity"] = "Email Activity"
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_6_0_emailactivity_classes_types_action_id_ActionId
    ] = None
    activity_id: ocsf_v_1_6_0_emailactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_6_0_emailactivity_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_6_0_emailactivity_objects_types_api_Api] = None
    attacks: typing.Optional[
        typing.List[ocsf_v_1_6_0_emailactivity_objects_types_attack_Attack]
    ] = None
    attempt: typing.Optional[int] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_6_0_emailactivity_objects_types_authorization_Authorization
        ]
    ] = None
    banner: typing.Optional[str] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_6_0_emailactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_6_0_emailactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_6_0_emailactivity_objects_types_cloud_Cloud] = None
    command: typing.Optional[str] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_6_0_emailactivity_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_6_0_emailactivity_objects_types_device_Device] = (
        None
    )
    direction: typing.Optional[str] = None
    direction_id: DirectionId
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_6_0_emailactivity_classes_types_disposition_id_DispositionId
    ] = None
    dst_endpoint: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    email: ocsf_v_1_6_0_emailactivity_objects_types_email_Email
    email_auth: typing.Optional[EmailAuth] = None
    end_time: typing.Optional[
        ocsf_v_1_6_0_emailactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_6_0_emailactivity_objects_types_enrichment_Enrichment]
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_firewall_rule_FirewallRule
    ] = None
    from_: typing.Optional[EmailAddress] = pydantic.Field(alias="from", default=None)
    is_alert: typing.Optional[bool] = None
    malware: typing.Optional[
        typing.List[ocsf_v_1_6_0_emailactivity_objects_types_malware_Malware]
    ] = None
    malware_scan_info: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_malware_scan_info_MalwareScanInfo
    ] = None
    message: typing.Optional[str] = None
    message_trace_uid: typing.Optional[str] = None
    metadata: ocsf_v_1_6_0_emailactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_6_0_emailactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_6_0_emailactivity_objects_types_osint_Osint]
    ] = None
    policy: typing.Optional[ocsf_v_1_6_0_emailactivity_objects_types_policy_Policy] = (
        None
    )
    protocol_name: typing.Optional[str] = None
    raw_data: typing.Optional[str] = None
    raw_data_hash: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_fingerprint_Fingerprint
    ] = None
    raw_data_size: typing.Optional[int] = None
    risk_details: typing.Optional[str] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_6_0_emailactivity_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_6_0_emailactivity_classes_types_severity_id_SeverityId
    smtp_hello: typing.Optional[str] = None
    src_endpoint: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_6_0_emailactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_6_0_emailactivity_classes_types_status_id_StatusId
    ] = None
    time: ocsf_v_1_6_0_emailactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    to: typing.Optional[typing.List[EmailAddress]] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_6_0_emailactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_6_0_emailactivity_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_CloudActivity(UncheckedBaseModel):
    class_name: typing.Literal["Cloud Activity"] = "Cloud Activity"
    activity_id: ocsf_v_1_3_0_cloudactivity_classes_types_activity_id_ActivityId
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_actor_Actor] = None
    api: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_api_Api] = None
    category_name: typing.Optional[str] = None
    category_uid: ocsf_v_1_3_0_cloudactivity_classes_types_category_uid_CategoryUid
    class_uid: ocsf_v_1_3_0_cloudactivity_classes_types_class_uid_ClassUid
    cloud: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_cloud_Cloud] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_object_Object
    ] = None
    device: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_device_Device] = (
        None
    )
    dst_endpoint: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    duration: typing.Optional[int] = None
    email: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_email_Email] = None
    end_time: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[ocsf_v_1_3_0_cloudactivity_objects_types_enrichment_Enrichment]
    ] = None
    file: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_file_File] = None
    http_request: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_http_request_HttpRequest
    ] = None
    http_response: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_http_response_HttpResponse
    ] = None
    meeting: typing.Optional[Meeting] = None
    message: typing.Optional[str] = None
    messaging: typing.Optional[Messaging] = None
    metadata: ocsf_v_1_3_0_cloudactivity_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[ocsf_v_1_3_0_cloudactivity_objects_types_observable_Observable]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_3_0_cloudactivity_objects_types_osint_Osint]
    ] = None
    parameters: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_object_Object
    ] = None
    raw_data: typing.Optional[str] = None
    severity: typing.Optional[str] = None
    severity_id: ocsf_v_1_3_0_cloudactivity_classes_types_severity_id_SeverityId
    sharing: typing.Optional[Sharing] = None
    src_app: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_product_Product
    ] = None
    src_endpoint: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_network_endpoint_NetworkEndpoint
    ] = None
    start_time: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_classes_types_status_id_StatusId
    ] = None
    target_app: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_product_Product
    ] = None
    time: ocsf_v_1_3_0_cloudactivity_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    tls: typing.Optional[ocsf_v_1_3_0_cloudactivity_objects_types_tls_Tls] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_3_0_cloudactivity_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_3_0_cloudactivity_objects_types_object_Object
    ] = None
    web_resources: typing.List[
        ocsf_v_1_3_0_cloudactivity_objects_types_web_resource_WebResource
    ]
    web_resources_result: typing.Optional[
        typing.List[ocsf_v_1_3_0_cloudactivity_objects_types_web_resource_WebResource]
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class Event_CloudResourcesInventoryInfo(UncheckedBaseModel):
    class_name: typing.Literal["Cloud Resources Inventory Info"] = (
        "Cloud Resources Inventory Info"
    )
    action: typing.Optional[str] = None
    action_id: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_action_id_ActionId
    ] = None
    activity_id: (
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_activity_id_ActivityId
    )
    activity_name: typing.Optional[str] = None
    actor: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_actor_Actor
    ] = None
    api: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_api_Api
    ] = None
    attacks: typing.Optional[
        typing.List[
            ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_attack_Attack
        ]
    ] = None
    authorizations: typing.Optional[
        typing.List[
            ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_authorization_Authorization
        ]
    ] = None
    category_name: typing.Optional[str] = None
    category_uid: (
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_category_uid_CategoryUid
    )
    class_uid: ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_class_uid_ClassUid
    cloud: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_cloud_Cloud
    ] = None
    confidence: typing.Optional[str] = None
    confidence_id: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_confidence_id_ConfidenceId
    ] = None
    confidence_score: typing.Optional[int] = None
    container: typing.Optional[Container] = None
    count: typing.Optional[int] = None
    custom_fields: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_object_Object
    ] = None
    database: typing.Optional[Database] = None
    databucket: typing.Optional[Databucket] = None
    device: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_device_Device
    ] = None
    disposition: typing.Optional[str] = None
    disposition_id: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_disposition_id_DispositionId
    ] = None
    duration: typing.Optional[int] = None
    end_time: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_base_types_timestamp_Timestamp
    ] = None
    end_time_dt: typing.Optional[dt.datetime] = None
    enrichments: typing.Optional[
        typing.List[
            ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_enrichment_Enrichment
        ]
    ] = None
    firewall_rule: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_firewall_rule_FirewallRule
    ] = None
    idp: typing.Optional[Idp] = None
    is_alert: typing.Optional[bool] = None
    malware: typing.Optional[
        typing.List[
            ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_malware_Malware
        ]
    ] = None
    message: typing.Optional[str] = None
    metadata: ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_metadata_Metadata
    observables: typing.Optional[
        typing.List[
            ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_observable_Observable
        ]
    ] = None
    osint: typing.Optional[
        typing.List[ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_osint_Osint]
    ] = None
    policy: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_policy_Policy
    ] = None
    raw_data: typing.Optional[str] = None
    region: typing.Optional[str] = None
    resources: typing.Optional[
        typing.List[
            ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_resource_details_ResourceDetails
        ]
    ] = None
    risk_details: typing.Optional[str] = None
    risk_level: typing.Optional[str] = None
    risk_level_id: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_risk_level_id_RiskLevelId
    ] = None
    risk_score: typing.Optional[int] = None
    severity: typing.Optional[str] = None
    severity_id: (
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_severity_id_SeverityId
    )
    start_time: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_base_types_timestamp_Timestamp
    ] = None
    start_time_dt: typing.Optional[dt.datetime] = None
    status: typing.Optional[str] = None
    status_code: typing.Optional[str] = None
    status_detail: typing.Optional[str] = None
    status_id: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_status_id_StatusId
    ] = None
    table: typing.Optional[Table] = None
    time: ocsf_v_1_4_0_cloudresourcesinventoryinfo_base_types_timestamp_Timestamp
    time_dt: typing.Optional[dt.datetime] = None
    timezone_offset: typing.Optional[int] = None
    type_name: typing.Optional[str] = None
    type_uid: ocsf_v_1_4_0_cloudresourcesinventoryinfo_classes_types_type_uid_TypeUid
    unmapped: typing.Optional[
        ocsf_v_1_4_0_cloudresourcesinventoryinfo_objects_types_object_Object
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


Event = typing_extensions.Annotated[
    typing.Union[
        Event_AccountChange,
        Event_ApiActivity,
        Event_ApplicationSecurityPostureFinding,
        Event_EntityManagement,
        Event_Authentication,
        Event_AuthorizeSession,
        Event_BaseEvent,
        Event_ComplianceFinding,
        Event_DeviceConfigState,
        Event_DetectionFinding,
        Event_DnsActivity,
        Event_HttpActivity,
        Event_FileSystemActivity,
        Event_GroupManagement,
        Event_IncidentFinding,
        Event_DeviceInventoryInfo,
        Event_ModuleActivity,
        Event_NetworkActivity,
        Event_ProcessActivity,
        Event_ScanActivity,
        Event_ScheduledJobActivity,
        Event_SecurityFinding,
        Event_SoftwareInfo,
        Event_UserAccessManagement,
        Event_VulnerabilityFinding,
        Event_WebResourceAccessActivity,
        Event_ApplicationLifecycle,
        Event_FileHostingActivity,
        Event_EmailActivity,
        Event_CloudActivity,
        Event_CloudResourcesInventoryInfo,
    ],
    UnionMetadata(discriminant="class_name"),
]
